@@ -1,9 +1,10 @@
 import argparse
 import pathlib
-from astunparse import unparse
 from typing import Optional, cast
 
 import black
+import isort
+from astunparse import unparse
 from graphql import parse
 
 from .core import visit_functions  # pylint: disable=unused-import
@@ -17,7 +18,7 @@ def app():
     output_path = make_path(args.output)
     schema = read_schema(gql_path)
     python_ast = schema_visitor.visit(parse(schema)).node
-    python_source = black.format_str(unparse(python_ast), mode=black.Mode())
+    python_source = black.format_str(isort.code(unparse(python_ast)), mode=black.Mode())
     write_to_output(python_source, output_path)
 
 
@@ -30,7 +31,7 @@ def parse_args():
 
 
 def read_schema(gql_path: pathlib.Path):
-    with open(gql_path) as schema:
+    with open(gql_path, encoding="utf-8") as schema:
         data = schema.read()
 
     return data
@@ -41,11 +42,11 @@ def write_to_output(python_source, output_path):
         print(python_source)
         return
 
-    with open(output_path, "w") as output:
+    with open(output_path, "w", encoding="utf-8") as output:
         output.write(python_source)
 
 
 def make_path(path: Optional[pathlib.Path]):
     if path is None:
-        return
+        return None
     return path if path.is_absolute() else pathlib.Path.cwd() / path
